==> zio-aws-docdb_2.13-5.17.146.1-sources.jar: zio/aws/docdb/model/DescribeCertificatesResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DescribeCertificatesResponse(
    certificates: Option[Iterable[zio.aws.docdb.model.Certificate]] = None,
    marker: Option[String] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse = {
    import DescribeCertificatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
      .builder()
      .optionallyWith(
        certificates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.certificates)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly =
    zio.aws.docdb.model.DescribeCertificatesResponse.wrap(buildAwsValue())
}
object DescribeCertificatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeCertificatesResponse =
      zio.aws.docdb.model.DescribeCertificatesResponse(
        certificates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def certificates: Option[List[zio.aws.docdb.model.Certificate.ReadOnly]]
    def marker: Option[String]
    def getCertificates
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.Certificate.ReadOnly]] =
      AwsError.unwrapOptionField("certificates", certificates)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ) extends zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly {
    override val certificates
        : Option[List[zio.aws.docdb.model.Certificate.ReadOnly]] = scala
      .Option(impl.certificates())
      .map(value =>
        value.asScala.map { item =>
          zio.aws.docdb.model.Certificate.wrap(item)
        }.toList
      )
    override val marker: Option[String] =
      scala.Option(impl.marker()).map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ): zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-docdb_2.13-6.20.61.1-sources.jar: zio/aws/docdb/model/DescribeCertificatesResponse.scala <==
package zio.aws.docdb.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DescribeCertificatesResponse(
    certificates: Optional[Iterable[zio.aws.docdb.model.Certificate]] =
      Optional.Absent,
    marker: Optional[String] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse = {
    import DescribeCertificatesResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
      .builder()
      .optionallyWith(
        certificates.map(value =>
          value.map { item =>
            item.buildAwsValue()
          }.asJavaCollection
        )
      )(_.certificates)
      .optionallyWith(marker.map(value => value: java.lang.String))(_.marker)
      .build()
  }
  def asReadOnly: zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly =
    zio.aws.docdb.model.DescribeCertificatesResponse.wrap(buildAwsValue())
}
object DescribeCertificatesResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.docdb.model.DescribeCertificatesResponse =
      zio.aws.docdb.model.DescribeCertificatesResponse(
        certificates.map(value =>
          value.map { item =>
            item.asEditable
          }
        ),
        marker.map(value => value)
      )
    def certificates: Optional[List[zio.aws.docdb.model.Certificate.ReadOnly]]
    def marker: Optional[String]
    def getCertificates
        : ZIO[Any, AwsError, List[zio.aws.docdb.model.Certificate.ReadOnly]] =
      AwsError.unwrapOptionField("certificates", certificates)
    def getMarker: ZIO[Any, AwsError, String] =
      AwsError.unwrapOptionField("marker", marker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ) extends zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly {
    override val certificates
        : Optional[List[zio.aws.docdb.model.Certificate.ReadOnly]] =
      zio.aws.core.internal
        .optionalFromNullable(impl.certificates())
        .map(value =>
          value.asScala.map { item =>
            zio.aws.docdb.model.Certificate.wrap(item)
          }.toList
        )
    override val marker: Optional[String] = zio.aws.core.internal
      .optionalFromNullable(impl.marker())
      .map(value => value: String)
  }
  def wrap(
      impl: software.amazon.awssdk.services.docdb.model.DescribeCertificatesResponse
  ): zio.aws.docdb.model.DescribeCertificatesResponse.ReadOnly = new Wrapper(
    impl
  )
}
